csep.core.catalogs.AbstractBaseCatalog
======================================

.. currentmodule:: csep.core.catalogs

.. autoclass:: AbstractBaseCatalog

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AbstractBaseCatalog.__init__
      ~AbstractBaseCatalog.apply_mct
      ~AbstractBaseCatalog.filter
      ~AbstractBaseCatalog.filter_spatial
      ~AbstractBaseCatalog.from_dataframe
      ~AbstractBaseCatalog.from_dict
      ~AbstractBaseCatalog.get_bvalue
      ~AbstractBaseCatalog.get_csep_format
      ~AbstractBaseCatalog.get_cumulative_number_of_events
      ~AbstractBaseCatalog.get_datetimes
      ~AbstractBaseCatalog.get_depths
      ~AbstractBaseCatalog.get_epoch_times
      ~AbstractBaseCatalog.get_event_ids
      ~AbstractBaseCatalog.get_latitudes
      ~AbstractBaseCatalog.get_longitudes
      ~AbstractBaseCatalog.get_mag_idx
      ~AbstractBaseCatalog.get_magnitudes
      ~AbstractBaseCatalog.get_number_of_events
      ~AbstractBaseCatalog.get_spatial_idx
      ~AbstractBaseCatalog.length_in_seconds
      ~AbstractBaseCatalog.load_catalog
      ~AbstractBaseCatalog.load_json
      ~AbstractBaseCatalog.magnitude_counts
      ~AbstractBaseCatalog.spatial_counts
      ~AbstractBaseCatalog.spatial_event_probability
      ~AbstractBaseCatalog.spatial_magnitude_counts
      ~AbstractBaseCatalog.to_dataframe
      ~AbstractBaseCatalog.to_dict
      ~AbstractBaseCatalog.update_catalog_stats
      ~AbstractBaseCatalog.write_ascii
      ~AbstractBaseCatalog.write_json
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AbstractBaseCatalog.catalog
      ~AbstractBaseCatalog.data
      ~AbstractBaseCatalog.dtype
      ~AbstractBaseCatalog.event_count
      ~AbstractBaseCatalog.log
   
   